@@ -1,23 +1,20 @@
-# NAME: CAD-OpenSCAD
-# ABSTRACT: Module to generate OpenSCAD files using Perl
-
-use strict; use warnings;
-
+use strict;
+use warnings;
 use Object::Pad;
 use CAD::OpenSCAD::Math;
 
-our $Math=new CAD::OpenSCAD::Math;
+our $Math=new Math;
 
-our $VERSION='0.12.2';
+our $VERSION='0.10';
 
 =head1 NAME
 
-CAD::OpenSCAD  
+CAD::OpenSCAD  Module to generate .scad file from Perl
 
-=head2 SYNOPSIS
+=head1 SYNOPSIS
 
      use CAD::OpenSCAD;
-     my $scad=new OpenSCAD;
+     my $scad=new SCAD;
      $scad->cube("main",[10,10,10],1)
           ->cylinder("hole",{r=>4,h=>20},1)
           ->difference("newObject","main","hole")
@@ -25,32 +22,32 @@ CAD::OpenSCAD
           ->save("testScad");
 
 
-=head2 DESCRIPTION
+=head1 DESCRIPTION
 
-This module allows creation of OpenSCAD scripts for running through OpenSCAD,
+This module allows creation of SCAD scripts for running through OpenSCAD,
 the "Programmers CAD Application". OpenSCAD can be scripted, having a
 fairly comprehensive language to create complex 3D objects.
 CAD::OpenSCAD allows generation and manipulation of 3D objects in a
 Perlish way,while relying on OpenSCAD to do all the hardwork, merely by
 generating SCAD scripts.
 
-=head2 MAIN METHODS
+=head1 MAIN METHODS
 
-Creating an  OpenSCAD object is by the standard methods.
+Creating a SCAD object is by the standard methods.
 Optional parameters are hash C<< key=>value >> pairs.
 valid keys are C<fa>, C<fs> and C<tab>
 
      use CAD::OpenSCAD;
-     my $scad=new OpenSCAD();
+     my $scad=new SCAD();
      # optionally can add fs, fa and tab on intialisation
-     # e.g my $scad=new OpenSCAD(fs=>1, fa=>0.4, tab=>0);
+     # e.g my $scad=new SCAD(fs=>1, fa=>0.4, tab=>0);
 
-New elements can be added to this OpenSCAD object; each object is named
+New elements can be added to this SCAD object; each object is named
 for subsequent transformations
 =cut
 
 
-class OpenSCAD{
+class SCAD{
    field $script :reader :param  //="";
    field $items  :reader :writer //={};
    field $fa     :writer :reader :param //=1;
@@ -67,16 +64,16 @@ class OpenSCAD{
    field $status :writer;
    field $extensions  ={};
 
-=head4 set_fs set_fa set_tab
+=head3 set_fs set_fa set_tab
 
 Using these, one can set parameters for the surface generation and script
 outputs. e.g.
 
   $scad->set_fa(10) 
 
-=head3 3D Primitive Shapes
+=head2 3D Primitive Shapes
 
-=head4 cube
+=head3 cube
 
 C<cube> creates a cube element e.g.
 
@@ -95,7 +92,7 @@ element is centered in the origin (a true value here centers the element)
       return $self;
    }
    
-=head4 cylinder
+=head3 cylinder
 
 Creates a cylinder element e.g.
 
@@ -113,7 +110,7 @@ the element is centered on the origin (a true value here centers the element)
       return $self;
   }
 
-=head4 sphere
+=head3 sphere
 
 Creates a sphere element e.g.
 
@@ -139,9 +136,9 @@ of defining radius of the sphere.
 
 
 
-=head3 Transformations
+=head2 Transformations
 
-=head4 translate
+=head3 translate
 
 Moves an element by name a specified displacement in X,Y,Z directions
 e.g. 
@@ -160,7 +157,7 @@ The second parameter is an arrayref of three elements defining displacement.
 	  
   }
 
-=head4 rotate
+=head3 rotate
 
 Rotates an element by name around X,Y,Z axes about the origin [0,0,0].e.g.
 
@@ -179,7 +176,7 @@ in degrees.
 	  
   }
   
-=head4 mirror
+=head3 mirror
 
 Mirrors an element by name about a plane. That plane is defined by the normal to that vector, 
 and the plane goes through the origin.
@@ -199,7 +196,7 @@ is an arrayref containg the planes normal e.g.[1,0,0] implies a mirroring about
 	  
   }
     
-=head4 resize
+=head3 resize
 
 Resizes an element by name to specified dimensions in X,Y,Z directions.e.g.
 
@@ -217,7 +214,7 @@ scale factors.
 	  
   }
   
-=head4 scale
+=head3 scale
 
 Scales an element by name by specified ratios in X,Y,Z directions.e.g.
 
@@ -234,7 +231,7 @@ The second parameter is an arrayref of three scale factors.
 	  
   } 
 
-=head4 multimatrix
+=head3 multimatrix
 
 Multiplies the geometry of all child elements with the given
 L<affine|https://en.wikipedia.org/wiki/Transformation_matrix#Affine_transformations>
@@ -249,7 +246,7 @@ with the 4th row always forced to [0,0,0,1].
 	  
   } 
 
-=head4 skew
+=head3 skew
 
 Uses MultiMatrix to transform a item by skewing in xy, yx, zy, yz, xz, zx  planes.
 this uses a matrix described in L<this gist|https://gist.github.com/boredzo/fde487c724a40a26fa9c>
@@ -278,7 +275,7 @@ this uses a matrix described in L<this gist|https://gist.github.com/boredzo/fde4
 
 
 
-=head4 offset
+=head3 offset
 
 Offset generates a new 2d interior or exterior outline from an existing outline.
 There are two modes of operation: radial and delta.
@@ -291,11 +288,11 @@ There are two modes of operation: radial and delta.
 	  
   } 
 
-=head4 hull
+=head3 hull
 
 Displays the convex hull of child nodes.
 
-	my $chart=new OpenSCAD;
+	my $chart=new SCAD;
 	my $pos=[0,0,0]; my @cubes=(); my @hulls=();
 	for (0..100){   # a hundred randomly displaced cubes
 		$chart->cube("dot$_",3)->translate("dot$_",$pos);
@@ -319,7 +316,7 @@ Displays the convex hull of child nodes.
 	  
   }   
 
-=head4 minkowski
+=head3 minkowski
 
 =cut
   
@@ -331,9 +328,9 @@ Displays the convex hull of child nodes.
   }   
   
   
-=head3 Boolean Operations
+=head2 Boolean Operations
 
-=head4  union
+=head3  union
 
 Implicitly joins multiple elements into one element.e.g.C<< $scad->union("wheel",qw/wheel nut nut1 nut2 nut3/); >>
 the first item is the name of the new element created, the following elements are elements to be joined together.
@@ -350,7 +347,7 @@ If an element with the name of the first parameter does not exist, it is created
   }
 
 
-=head4 difference
+=head3 difference
 
 Subtracts one or more elements from one element and creates a new element.
 e.g.
@@ -373,7 +370,7 @@ in "wheel" (first parameter).
       return $self;
   }  
   
-=head4 intersection
+=head3 intersection
 
 Creates an element representing the overlapping parts of 2 or more elements
 .e.g.
@@ -393,9 +390,9 @@ elements which overlap neach other.
       return $self;
   }  
 
-=head3 2D Primitive Shapes
+=head2 2D Primitive Shapes
 
-=head4 circle
+=head3 circle
 
 A 2D drawing primitive that creates a circle that may be extruded to create other 3D structures.
 e.g
@@ -409,7 +406,7 @@ e.g
       return $self;
   }
   
-=head4 square
+=head3 square
 
 a 2D drawing primitive that creates a rectangle that may be extruded to create other 3D structures.
 e.g 
@@ -424,12 +421,12 @@ $scad->square("square",[10,10]);
       return $self;
   }
 
-=head4 polygon
+=head3 polygon
 
 A 2D drawing primitive that creates a polygon that may be extruded to create other 3D structures .
 Example:- 
 
-  my $extrusion=new OpenSCAD;
+  my $extrusion=new SCAD;
   $extrusion->variable({p0=>[0, 0],p1 => [0, -30],p2 => [15, 30],p3=> [35, 20],p4 => [35, 0]})
             ->variable("points",[qw/p0 p1 p2 p3 p4 /] )
             ->polygon("poly","points")
@@ -443,7 +440,7 @@ Example:-
       return $self;
   }
 
-=head4 text
+=head3 text
 
 Allows 2D text shapes to be created, that may be extruded and manipulated like other items
 e.g. 
@@ -472,13 +469,13 @@ to just use defaults.
   }
 
 
-=head3 Extrusion
+=head2 Extrusion
 
-=head4 rotate_extrude
+=head3 rotate_extrude
 
 A method to extrude a 2D shape while rotating invokes similar to liner_extrude
 
-  my $extrusion=new OpenSCAD;
+  my $extrusion=new SCAD;
   $extrusion->circle("circle",{r=>5})
             ->translate("circle",[10,0,0])
             ->rotate_extrude("circle",{angle=>180});
@@ -491,7 +488,7 @@ A method to extrude a 2D shape while rotating invokes similar to liner_extrude
       return $self;
   }  
 
-=head4 liner_extrude
+=head3 liner_extrude
 
 A method to extrude a 2D shape see above for example
 =cut
@@ -503,7 +500,7 @@ A method to extrude a 2D shape see above for example
   }  
 
 
-=head4 color
+=head3 color
 
 colors an item e.g. . 
 
@@ -527,7 +524,7 @@ colors an item e.g. .
 	  $scr=$tabs.(join "\n$tabs", (split "\n",$scr))."\n";
 	  return $scr;
   }
-=head4 clone
+=head3 clone
 
 Creates copies of elements with same features. e.g.
 
@@ -572,7 +569,7 @@ This just copies the code for the element into new elements, for subsequent tran
     
 
     
-=head4 variable
+=head3 variable
 
 Creates variables that SCAD can use for customising objects easily 
 (see polygon example above)
@@ -614,9 +611,9 @@ Creates variables that SCAD can use for customising objects easily
       return $dims;
   }
   
-=head3 Build and Save
+=head2 Build and Save
   
-=head4 build
+=head3 build
 
 Collects the elements specified (i.e. not all the elements, just the items required for the build)
 and all the variables to generate a scad file.  The scad file generated include all the variables defined,
@@ -648,7 +645,7 @@ the modules built and the libraries used
 	  }
 	  return $self;
   }
-=head4 save
+=head3 save
 
 saves the .scad file, and also uses openscad to generate images or 3D objects
 from the script, or open it in openSCAD directly after building the shape;
@@ -735,20 +732,19 @@ e.g. C<< $scad->save("extrusion","png") >>
 }
 
 
-class scadItem{
-   field $name            :reader :param  ;
-   field $description     :reader :writer :param  //="";
-   field $script          :reader :param  //="";
-   field $insPoint        :reader :writer :param //=[0,0];
-   field $rotation        :reader :writer :param //=[0,0,0];
+class Item{
+   field $name     :reader :param  ;
+   field $description     :reader :param  //="";
+   field $script   :reader :param  //="";
+   field $insPoint :reader :writer :param //=[0,0];
+   field $rotation :reader :writer :param //=[0,0,0];
    field $vertices  = [];
    field $faces  = [];
 }
 
-=head2 SUPPORT
-
-=head2 COPYRIGHT AND DISCLAIMERS
+=head1 SUPPORT
 
+=head1 COPYRIGHT AND DISCLAIMERS
 Copyright (c) 2025 Saif Ahmed.
 
 This library is free software; you can redistribute it and/or
@@ -759,11 +755,9 @@ but without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 
-=head2 AUTHOR
-
+=head1 AUTHOR
 SAIFTYNET
 
-=head2 CONTRIBUTORS
-
+=head1 CONTRIBUTORS
 jmlynesjr
 =cut
